function pval = xarsieve_skewness(y, B)

%=======================================================================================
% PURPOSE:
% calculates the P-values of 3 skewness-based statistics using AR-sieve bootstrap
% 
% INPUT:
%   y = (nx1) vector of observations (stationary series only!)
%   B = # of btsp replications (B = 1000 recommended)
%
% OUTPUT:
%   pval = (1 x 3) vector of P-values for individual statistics
%
% AUTHOR:
% Marian Vavra (marian.vavra@gmail.com)
%
% REFERENCES:
% [1] Buhlmann (1997), Bernouli, 3
% [2] Psaradakis (2016), Journal of Business and Econimic Statistics
%=======================================================================================

n = length(y);

% values of the test statistics from the original sample
psi_0 = xtest_skewness(y);

% AR-sieve for btsp
pmax   = floor((log(n))^2);
p      = xautolag(y,'AIC',pmax);
Ylag   = mlag(y,p,1);
Y      = y(p+1:end);
[Q1,R1]= qr(Ylag,0);
phi    = R1\(Q1'*Y);
e      = Y - Ylag*phi;
E = [e;-e];

% stationarity condition for the AR-sieve bootstrap
param = abs(sum(phi(2:end)));
if param > 0.95
    phi = [phi(1);0.95*phi(2:end)./param];
end

% bootstrap copies 
N = n+100;
PSI_b = zeros(B,3);

for ii=1:B
    index = random('unid',length(E),N,1);
    eb = E(index);
    yb = [mean(y)*ones(p,1); zeros(N-p,1)];
    for t=p+1:N
        yb(t) = phi'*[1;yb(t-1:-1:t-p)] + eb(t);
    end
    yb = yb(101:end);
    PSI_b(ii,1:3) = xtest_skewness(yb);
end

pval1 = mean(abs(PSI_b(:,1)) > abs(psi_0(1)));
pval2 = mean(abs(PSI_b(:,2)) > abs(psi_0(2)));
pval3 = mean(abs(PSI_b(:,3)) > abs(psi_0(3)));
pval = [pval1, pval2, pval3];